@@ -6,8 +6,10 @@ Centralizing these functions reduces code duplication and provides a single plac
 for common CLI operations.
 """
 
+import difflib
 import sys
-from typing import Optional
+from pathlib import Path
+from typing import List, Optional
 
 from ..core.logger import get_logger
 
@@ -37,13 +39,11 @@ def get_user_input(input_arg: Optional[str], logger) -> str:
         if input_path.exists():
             logger.info(f"Reading input from file: {input_path}")
             return input_path.read_text()
-        else:
-            logger.info("Using command line input")
-            return input_arg
-    else:
-        # Read from stdin
-        logger.info("Reading input from stdin")
-        return sys.stdin.read()
+        logger.info("Using command line input")
+        return input_arg
+    # Read from stdin
+    logger.info("Reading input from stdin")
+    return sys.stdin.read()
 
 
 def get_agent_versions_display() -> Optional[str]:
@@ -107,7 +107,7 @@ def get_agent_versions_display() -> Optional[str]:
                     base_version_tuple
                 )
                 output_lines.append(f"\n  Base Agent Version:  {base_version_str}")
-        except:
+        except Exception:
             pass
 
         # Check for agents needing migration
@@ -115,7 +115,7 @@ def get_agent_versions_display() -> Optional[str]:
             output_lines.append(
                 f"\n  ⚠️  {len(verification['agents_needing_migration'])} agent(s) need migration to semantic versioning"
             )
-            output_lines.append(f"     Run 'claude-mpm agents deploy' to update")
+            output_lines.append("     Run 'claude-mpm agents deploy' to update")
 
         output_lines.append("-" * 40)
         return "\n".join(output_lines)
@@ -132,16 +132,17 @@ def list_agent_versions_at_startup() -> None:
 
     WHY: Users want to see what agents are available when they start a session.
     This provides immediate feedback about the deployed agent environment.
-    
+
     DESIGN DECISION: We suppress INFO logging during this call to avoid duplicate
     initialization messages since the deployment service will be initialized again
     later in the ClaudeRunner.
     """
     # Temporarily suppress INFO level logging to avoid duplicate initialization messages
     import logging
+
     original_level = logging.getLogger("claude_mpm").level
     logging.getLogger("claude_mpm").setLevel(logging.WARNING)
-    
+
     try:
         agent_versions = get_agent_versions_display()
         if agent_versions:
@@ -166,7 +167,6 @@ def setup_logging(args) -> object:
         Logger instance
     """
     from ..constants import LogLevel
-    from ..core.logger import get_logger
     from ..core.logger import setup_logging as core_setup_logging
 
     # Set default logging level if not specified
@@ -208,3 +208,53 @@ def ensure_directories() -> None:
         # Continue even if initialization fails
         # The individual commands will handle missing directories as needed
         pass
+
+
+def suggest_similar_commands(
+    invalid_command: str,
+    valid_commands: List[str],
+    cutoff: float = 0.6,
+    max_suggestions: int = 3,
+) -> Optional[str]:
+    """
+    Suggest similar commands for an invalid command using fuzzy matching.
+
+    WHY: Helps users quickly identify typos and discover correct command names
+    by suggesting the most similar valid commands. Uses stdlib difflib for
+    zero-dependency fuzzy matching.
+
+    DESIGN DECISION: Using difflib.get_close_matches provides good results for
+    typos and partial matches while being simple and lightweight (no external deps).
+
+    Args:
+        invalid_command: The invalid command the user typed
+        valid_commands: List of valid commands to match against
+        cutoff: Similarity threshold (0.0-1.0), default 0.6
+        max_suggestions: Maximum number of suggestions to return, default 3
+
+    Returns:
+        Formatted suggestion string or None if no good matches found
+
+    Examples:
+        >>> suggest_similar_commands("tickts", ["tickets", "run", "agents"])
+        "Did you mean 'tickets'?"
+
+        >>> suggest_similar_commands("mem", ["memory", "monitor", "mcp"])
+        "Did you mean one of these?\n  memory\n  monitor\n  mcp"
+
+        >>> suggest_similar_commands("xyz", ["tickets", "run"])
+        None  # No good matches
+    """
+    # Use difflib to find close matches
+    matches = difflib.get_close_matches(
+        invalid_command, valid_commands, n=max_suggestions, cutoff=cutoff
+    )
+
+    if not matches:
+        return None
+
+    # Format suggestion message
+    if len(matches) == 1:
+        return f"Did you mean '{matches[0]}'?"
+    suggestions = "\n  ".join(matches)
+    return f"Did you mean one of these?\n  {suggestions}"
