@@ -16,20 +16,15 @@ strict type safety.
 
 import logging
 from datetime import datetime
-from enum import Enum
 from typing import (
-    TYPE_CHECKING,
     Any,
-    AsyncIterator,
     Awaitable,
     Callable,
     Dict,
-    Iterator,
     List,
     Literal,
     Optional,
     Protocol,
-    Set,
     Tuple,
     TypeVar,
     Union,
@@ -37,9 +32,7 @@ from typing import (
 
 from typing_extensions import NotRequired, TypeAlias, TypedDict
 
-if TYPE_CHECKING:
-    from claude_mpm.core.claude_runner import ClaudeRunner
-    from claude_mpm.services.socketio_server import SocketIOClientProxy
+from claude_mpm.core.enums import OperationResult, ServiceState
 
 # Generic type variables
 T = TypeVar("T")
@@ -51,15 +44,14 @@ TService = TypeVar("TService")  # Generic service type
 PathLike: TypeAlias = Union[str, Path]
 JSONValue: TypeAlias = Union[str, int, float, bool, None, Dict[str, Any], List[Any]]
 JSONDict: TypeAlias = Dict[str, JSONValue]
+
 Headers: TypeAlias = Dict[str, str]
 ErrorCode: TypeAlias = Union[int, str]
 LogLevel: TypeAlias = Literal["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]
 
 # Session types
 SessionId: TypeAlias = str
-SessionStatus: TypeAlias = Literal[
-    "initializing", "running", "stopped", "error", "completed"
-]
+SessionStatus: TypeAlias = ServiceState  # Replaced Literal with ServiceState enum
 LaunchMethod: TypeAlias = Literal["exec", "subprocess", "oneshot"]
 
 
@@ -161,7 +153,7 @@ class WebSocketMessage(TypedDict):
 class ClaudeStatus(TypedDict):
     """Claude process status."""
 
-    status: Literal["starting", "running", "stopped", "error"]
+    status: ServiceState  # Replaced Literal with ServiceState enum
     message: str
     timestamp: NotRequired[datetime]
     pid: NotRequired[int]
@@ -172,7 +164,7 @@ class DelegationInfo(TypedDict):
 
     agent: AgentId
     task: str
-    status: Literal["detected", "started", "completed", "failed"]
+    status: OperationResult  # Replaced Literal with OperationResult enum
     timestamp: NotRequired[datetime]
     result: NotRequired[str]
 
@@ -203,7 +195,7 @@ class HookContext(TypedDict):
 
 # Service types
 ServiceName: TypeAlias = str
-ServiceStatus: TypeAlias = Literal["idle", "running", "stopped", "error"]
+ServiceStatus: TypeAlias = ServiceState  # Replaced Literal with ServiceState enum
 
 
 class ServiceConfig(TypedDict):
@@ -488,74 +480,74 @@ ErrorResult = Tuple[bool, Optional[str]]
 SuccessResult = Tuple[bool, Any]
 
 __all__ = [
-    # Basic type aliases
-    "PathLike",
-    "JSONValue",
-    "JSONDict",
-    "Headers",
-    "ErrorCode",
-    "LogLevel",
-    # Session types
-    "SessionId",
-    "SessionStatus",
-    "LaunchMethod",
-    "SessionConfig",
-    "SessionResult",
-    "SessionEvent",
+    "AgentCapabilities",
+    "AgentDefinition",
     # Agent types
     "AgentId",
-    "AgentVersion",
-    "AgentTier",
-    "ModelName",
-    "ResourceTier",
-    "AgentCapabilities",
     "AgentMetadata",
-    "AgentDefinition",
+    "AgentServiceProtocol",
+    "AgentTier",
+    "AgentVersion",
+    "ClaudeStatus",
+    "CommandArgs",
+    "CommandName",
+    "CommandResult",
+    # Common combinations
+    "CommonTypes",
+    "ConfigDict",
+    "DelegationInfo",
+    "DeploymentResult",
+    "ErrorCode",
+    "ErrorResult",
+    "EventData",
     # WebSocket types
     "EventName",
-    "EventData",
-    "SocketId",
-    "WebSocketMessage",
-    "ClaudeStatus",
-    "DelegationInfo",
+    "Headers",
+    "HookConfig",
+    "HookContext",
     # Hook types
     "HookName",
     "HookPriority",
     "HookResult",
-    "HookConfig",
-    "HookContext",
+    "JSONDict",
+    "JSONValue",
+    "LaunchMethod",
+    "LogLevel",
+    "LoggerProtocol",
+    "Memory",
+    "MemoryId",
+    "MemorySearchResult",
+    "MemoryServiceProtocol",
+    # Memory types
+    "MemoryType",
+    "ModelName",
+    # Basic type aliases
+    "PathLike",
+    # Other types
+    "ProjectConfig",
+    "ResourceTier",
+    "ResponseLogEntry",
+    "ServiceConfig",
+    "ServiceContainer",
+    "ServiceInfo",
     # Service types
     "ServiceName",
     "ServiceStatus",
-    "ServiceConfig",
-    "ServiceInfo",
-    # Memory types
-    "MemoryType",
-    "MemoryId",
-    "Memory",
-    "MemorySearchResult",
-    # Other types
-    "ProjectConfig",
-    "DeploymentResult",
-    "ResponseLogEntry",
-    "CommandName",
-    "CommandArgs",
-    "CommandResult",
+    "SessionConfig",
+    "SessionEvent",
+    # Session types
+    "SessionId",
     # Protocols
     "SessionProtocol",
-    "LoggerProtocol",
-    "WebSocketServerProtocol",
-    "AgentServiceProtocol",
-    "MemoryServiceProtocol",
-    "ServiceContainer",
+    "SessionResult",
+    "SessionStatus",
+    "SocketId",
+    "SuccessResult",
     # Generic type variables
     "T",
-    "TSession",
     "TAgent",
     "TService",
-    # Common combinations
-    "CommonTypes",
-    "ConfigDict",
-    "ErrorResult",
-    "SuccessResult",
+    "TSession",
+    "WebSocketMessage",
+    "WebSocketServerProtocol",
 ]
