@@ -83,11 +83,12 @@ class PathContext:
             # Check if we're in a src/ directory structure with pyproject.toml
             current = module_path
             for _ in range(5):  # Check up to 5 levels up
-                if (current / "pyproject.toml").exists():
-                    # Found pyproject.toml, check if this looks like a development setup
-                    if (current / "src" / "claude_mpm").exists():
-                        logger.debug(f"Found development installation at {current}")
-                        return True
+                if (current / "pyproject.toml").exists() and (
+                    current / "src" / "claude_mpm"
+                ).exists():
+                    # Found pyproject.toml with development setup
+                    logger.debug(f"Found development installation at {current}")
+                    return True
                 if current == current.parent:
                     break
                 current = current.parent
@@ -167,7 +168,7 @@ class PathContext:
 
     @staticmethod
     @lru_cache(maxsize=1)
-    def detect_deployment_context() -> DeploymentContext:  # noqa: PLR0911
+    def detect_deployment_context() -> DeploymentContext:
         """Detect the current deployment context.
 
         Priority order:
@@ -396,7 +397,7 @@ class UnifiedPathManager:
                     return current
                 current = current.parent
 
-            raise FileNotFoundError("Could not determine framework root")
+            raise FileNotFoundError("Could not determine framework root") from None
 
     @property
     @lru_cache(maxsize=1)
