@@ -25,6 +25,7 @@ import requests
 
 from ...core.logging_config import get_logger
 from ...services.monitor.daemon import UnifiedMonitorDaemon
+from ...services.monitor.daemon_manager import DaemonManager
 from ...services.port_manager import PortManager
 
 
@@ -99,8 +100,9 @@ class UnifiedDashboardManager(IUnifiedDashboardManager):
                 host="localhost", port=port, daemon_mode=background
             )
 
-            # Check if it's our service running
-            is_ours, pid = daemon.lifecycle.is_our_service("localhost")
+            # Use daemon manager to check service ownership
+            daemon_mgr = DaemonManager(port=port, host="localhost")
+            is_ours, pid = daemon_mgr.is_our_service()
 
             if is_ours and not force_restart:
                 # Our service is already running, just open browser if needed
@@ -115,46 +117,60 @@ class UnifiedDashboardManager(IUnifiedDashboardManager):
                 self.logger.info(
                     f"Force restarting our dashboard on port {port} (PID: {pid})"
                 )
-                # Clean up the existing service before restart
-                self._cleanup_port_conflicts(port)
+                # Don't cleanup here - let daemon.start(force_restart=True) handle it
+                # This prevents race conditions where we kill the service we're trying to start
             elif self.is_dashboard_running(port) and not force_restart:
-                # Different service is using the port - try to clean it up
-                self.logger.warning(f"Port {port} is in use by a different service, attempting cleanup")
-                self._cleanup_port_conflicts(port)
-                # Brief pause to ensure cleanup is complete
-                import time
-                time.sleep(1)
+                # Different service is using the port - don't clean it up without force_restart
+                self.logger.warning(
+                    f"Port {port} is in use by a different service. Use force_restart to override."
+                )
+                return False, False
 
             self.logger.info(
                 f"Starting unified dashboard on port {port} (background: {background}, force_restart: {force_restart})"
             )
 
             if background:
+                # The daemon.start() method will handle cleanup when force_restart=True
+                # We don't need pre-emptive cleanup here as it causes race conditions
+
                 # Try to start daemon with retry on port conflicts
                 max_retries = 3
                 retry_count = 0
                 success = False
-                
+
                 while retry_count < max_retries and not success:
                     if retry_count > 0:
-                        self.logger.info(f"Retry {retry_count}/{max_retries}: Cleaning up port {port}")
-                        self._cleanup_port_conflicts(port)
-                        time.sleep(2)  # Wait for cleanup to complete
-                    
-                    # Start daemon in background mode with force restart if needed
-                    success = daemon.start(force_restart=force_restart or retry_count > 0)
-                    
+                        # Only cleanup on retries, not on first attempt
+                        self.logger.info(
+                            f"Retry {retry_count}/{max_retries}: Cleaning up port {port}"
+                        )
+                        daemon_mgr = DaemonManager(port=port, host="localhost")
+                        if not daemon_mgr.cleanup_port_conflicts():
+                            self.logger.error(f"Cleanup failed on retry {retry_count}")
+                            break
+                        time.sleep(3)  # Longer wait for cleanup to complete
+
+                    # Start daemon in background mode with force restart
+                    # The daemon.start() method handles its own cleanup when force_restart=True
+                    success = daemon.start(force_restart=force_restart)
+
                     if not success and retry_count < max_retries - 1:
                         # Check if it's a port conflict
                         if not self.port_manager.is_port_available(port):
-                            self.logger.warning(f"Port {port} still in use, will retry cleanup")
+                            self.logger.warning(
+                                f"Port {port} still in use, will retry cleanup"
+                            )
                             retry_count += 1
                         else:
                             # Different kind of failure, don't retry
+                            self.logger.error(
+                                "Daemon start failed for reason other than port conflict"
+                            )
                             break
                     else:
                         break
-                
+
                 if success:
                     with self._lock:
                         self._background_daemons[port] = daemon
@@ -318,14 +334,18 @@ class UnifiedDashboardManager(IUnifiedDashboardManager):
         Returns:
             Tuple of (dependencies_ok, error_message)
         """
-        try:
-            import aiohttp
-            import socketio
+        import importlib.util
 
-            return True, None
-        except ImportError as e:
-            error_msg = f"Required dependencies missing: {e}"
+        missing = []
+        if importlib.util.find_spec("aiohttp") is None:
+            missing.append("aiohttp")
+        if importlib.util.find_spec("socketio") is None:
+            missing.append("socketio")
+
+        if missing:
+            error_msg = f"Required dependencies missing: {', '.join(missing)}"
             return False, error_msg
+        return True, None
 
     def find_available_port(self, preferred_port: int = 8765) -> int:
         """
@@ -342,80 +362,17 @@ class UnifiedDashboardManager(IUnifiedDashboardManager):
     def _cleanup_port_conflicts(self, port: int) -> bool:
         """
         Try to clean up any processes using our port.
-        
+
+        Delegates to the consolidated DaemonManager for consistent behavior.
+
         Args:
             port: Port to clean up
-            
+
         Returns:
             True if cleanup was successful or not needed
         """
-        try:
-            import subprocess
-            import signal
-            import time
-            
-            # Find processes using the port
-            result = subprocess.run(
-                ["lsof", "-ti", f":{port}"],
-                capture_output=True,
-                text=True
-            )
-            
-            if result.returncode == 0 and result.stdout.strip():
-                pids = result.stdout.strip().split('\n')
-                self.logger.info(f"Found processes using port {port}: {pids}")
-                
-                for pid_str in pids:
-                    try:
-                        pid = int(pid_str.strip())
-                        # Try graceful termination first
-                        import os
-                        os.kill(pid, signal.SIGTERM)
-                        self.logger.info(f"Sent SIGTERM to process {pid}")
-                    except (ValueError, ProcessLookupError) as e:
-                        self.logger.debug(f"Could not terminate process {pid_str}: {e}")
-                        continue
-                
-                # Give processes time to shut down gracefully
-                time.sleep(3)
-                
-                # Check if port is still in use and force kill if needed
-                result = subprocess.run(
-                    ["lsof", "-ti", f":{port}"],
-                    capture_output=True,
-                    text=True
-                )
-                
-                if result.returncode == 0 and result.stdout.strip():
-                    remaining_pids = result.stdout.strip().split('\n')
-                    self.logger.warning(f"Processes still using port {port}: {remaining_pids}, force killing")
-                    
-                    for pid_str in remaining_pids:
-                        try:
-                            pid = int(pid_str.strip())
-                            os.kill(pid, signal.SIGKILL)
-                            self.logger.info(f"Force killed process {pid}")
-                        except (ValueError, ProcessLookupError) as e:
-                            self.logger.debug(f"Could not force kill process {pid_str}: {e}")
-                            continue
-                    
-                    # Brief pause after force kill to ensure port is released
-                    time.sleep(2)
-                
-                self.logger.info(f"Successfully cleaned up processes on port {port}")
-                return True
-            else:
-                self.logger.debug(f"No processes found using port {port}")
-                return True
-                
-        except FileNotFoundError:
-            # lsof not available, try alternative approach
-            self.logger.debug("lsof not available, skipping port cleanup")
-            return True
-        except Exception as e:
-            self.logger.warning(f"Error during port cleanup: {e}")
-            # Continue anyway - the port check will catch actual conflicts
-            return True
+        daemon_mgr = DaemonManager(port=port, host="localhost")
+        return daemon_mgr.cleanup_port_conflicts()
 
     def start_server(
         self, port: Optional[int] = None, timeout: int = 30, force_restart: bool = True
