@@ -14,6 +14,7 @@ import re
 from pathlib import Path
 from typing import Any, ClassVar, Dict, List, Optional
 
+from claude_mpm.core.enums import OperationResult
 from claude_mpm.core.logging_utils import get_logger
 
 from ..strategies import (
@@ -198,14 +199,14 @@ class SecurityAnalyzerStrategy(AnalyzerStrategy):
                 return self._analyze_directory(target_path, options)
 
         return {
-            "status": "error",
+            "status": OperationResult.ERROR,
             "message": f"Unsupported target type: {type(target).__name__}",
         }
 
     def _analyze_file(self, file_path: Path, options: Dict[str, Any]) -> Dict[str, Any]:
         """Analyze a single file for security issues."""
         results = {
-            "status": "success",
+            "status": OperationResult.SUCCESS,
             "type": "file",
             "path": str(file_path),
             "vulnerabilities": [],
@@ -241,7 +242,7 @@ class SecurityAnalyzerStrategy(AnalyzerStrategy):
 
         except Exception as e:
             logger.error(f"Error analyzing file {file_path}: {e}")
-            results["status"] = "error"
+            results["status"] = OperationResult.ERROR
             results["error"] = str(e)
 
         return results
@@ -251,7 +252,7 @@ class SecurityAnalyzerStrategy(AnalyzerStrategy):
     ) -> Dict[str, Any]:
         """Analyze all files in a directory for security issues."""
         results = {
-            "status": "success",
+            "status": OperationResult.SUCCESS,
             "type": "directory",
             "path": str(dir_path),
             "files_analyzed": 0,
@@ -301,7 +302,7 @@ class SecurityAnalyzerStrategy(AnalyzerStrategy):
 
                 file_result = self._analyze_file(file_path, options)
                 if (
-                    file_result["status"] == "success"
+                    file_result["status"] == OperationResult.SUCCESS
                     and file_result["vulnerabilities"]
                 ):
                     results["files"].append(file_result)
@@ -645,7 +646,7 @@ class SecurityAnalyzerStrategy(AnalyzerStrategy):
         """Extract key metrics from analysis results."""
         metrics = {}
 
-        if analysis_result.get("status") != "success":
+        if analysis_result.get("status") != OperationResult.SUCCESS:
             return metrics
 
         if analysis_result.get("type") == "file":
