@@ -19,6 +19,7 @@ from typing import Any, Dict, List, Optional
 
 import yaml
 
+from claude_mpm.core.enums import HealthStatus, OperationResult
 from claude_mpm.core.logging_utils import get_logger
 from claude_mpm.services.unified.strategies import StrategyMetadata, StrategyPriority
 
@@ -272,14 +273,14 @@ class LocalDeploymentStrategy(DeploymentStrategy):
         deployed_path = Path(deployment_info.get("deployed_path", ""))
 
         health = {
-            "status": "unknown",
+            "status": OperationResult.UNKNOWN,
             "deployed_path": str(deployed_path),
             "exists": deployed_path.exists() if deployed_path else False,
             "checks": {},
         }
 
         if deployed_path and deployed_path.exists():
-            health["status"] = "healthy"
+            health["status"] = OperationResult.SUCCESS
 
             # Check file integrity
             for file_path in deployment_info.get("deployed_files", []):
@@ -288,10 +289,10 @@ class LocalDeploymentStrategy(DeploymentStrategy):
 
             # Check if any file is missing
             if any(not check for check in health["checks"].values()):
-                health["status"] = "degraded"
+                health["status"] = HealthStatus.DEGRADED
 
         else:
-            health["status"] = "unhealthy"
+            health["status"] = HealthStatus.UNHEALTHY
 
         return health
 
