@@ -24,6 +24,7 @@ Features:
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 
+from claude_mpm.core.enums import OperationResult, ServiceState
 from claude_mpm.core.logging_utils import get_logger
 
 from .interfaces import (
@@ -140,7 +141,7 @@ class UnifiedDeploymentService(IDeploymentService, IUnifiedService):
 
         return {
             "service": "UnifiedDeploymentService",
-            "status": "healthy" if self._initialized else "unhealthy",
+            "status": ServiceState.RUNNING if self._initialized else ServiceState.ERROR,
             "initialized": self._initialized,
             "registered_strategies": len(strategies),
             "active_deployments": len(self._deployments),
@@ -304,7 +305,7 @@ class UnifiedDeploymentService(IDeploymentService, IUnifiedService):
             }
 
             # Update metrics
-            if result.get("success", False):
+            if result.get(OperationResult.SUCCESS.value, False):
                 self._metrics["successful_deployments"] += 1
                 deployed_path = Path(target) / Path(source).name
 
@@ -318,7 +319,7 @@ class UnifiedDeploymentService(IDeploymentService, IUnifiedService):
             self._metrics["failed_deployments"] += 1
             return DeploymentResult(
                 success=False,
-                message=result.get("error", "Deployment failed"),
+                message=result.get(OperationResult.ERROR.value, "Deployment failed"),
                 metadata=result,
             )
 
@@ -426,7 +427,11 @@ class UnifiedDeploymentService(IDeploymentService, IUnifiedService):
 
         return {
             "id": deployment_id,
-            "status": "rolled_back" if deployment.get("rolled_back") else "active",
+            "status": (
+                OperationResult.CANCELLED
+                if deployment.get("rolled_back")
+                else OperationResult.SUCCESS
+            ),
             "type": deployment["type"],
             "strategy": deployment["strategy"],
             "source": deployment["source"],
