@@ -274,7 +274,9 @@ class ConflictResolutionManager:
             )
 
         try:
-            with open(full_path, encoding="utf-8") as f:
+            with Path(full_path).open(
+                encoding="utf-8",
+            ) as f:
                 content = f.read()
 
             # Parse conflict markers
@@ -321,7 +323,7 @@ class ConflictResolutionManager:
 
         # Check content (simple heuristic)
         try:
-            with open(file_path, "rb") as f:
+            with file_path.open("rb") as f:
                 chunk = f.read(1024)
                 if b"\0" in chunk:
                     return True
@@ -587,7 +589,9 @@ class ConflictResolutionManager:
 
         try:
             # Read current content
-            with open(file_path, encoding="utf-8") as f:
+            with Path(file_path).open(
+                encoding="utf-8",
+            ) as f:
                 content = f.read()
 
             # Apply resolution strategy
@@ -596,7 +600,7 @@ class ConflictResolutionManager:
             )
 
             # Write resolved content
-            with open(file_path, "w", encoding="utf-8") as f:
+            with file_path.open("w", encoding="utf-8") as f:
                 f.write(resolved_content)
 
             return ConflictResolution(
